@@ -178,12 +178,12 @@ class ConsumersManager:
                     t.join()
             elif cls.global_concurrent_mode == 2:
                 # cls.logger.info()
-                nb_print(cls.schedulal_thread_to_be_join)
+                # nb_print(cls.schedulal_thread_to_be_join)
                 gevent.joinall(cls.schedulal_thread_to_be_join, raise_error=True, )
             elif cls.global_concurrent_mode == 3:
                 for g in cls.schedulal_thread_to_be_join:
                     # eventlet.greenthread.GreenThread.
-                    nb_print(g)
+                    # nb_print(g)
                     g.wait()
 
     @classmethod
@@ -196,8 +196,6 @@ class ConsumersManager:
                              f' \033[0;30;44m{consumer_info["queue_name"]} 的消费者\033[0m\n')
             cls._has_show_conusmers_info = True
 
-
-
     @staticmethod
     def get_concurrent_name_by_concurrent_mode(concurrent_mode):
         if concurrent_mode == 1:
@@ -241,7 +239,8 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def publisher_of_same_queue(self):
         if not self._publisher_of_same_queue:
             self._publisher_of_same_queue = get_publisher(self._queue_name, consuming_function=self.consuming_function,
-                                                          broker_kind=self.BROKER_KIND, log_level_int=self._log_level)
+                                                          broker_kind=self.BROKER_KIND, log_level_int=self._log_level,
+                                                          is_add_file_handler=self._create_logger_file)
             if self._msg_expire_senconds:
                 self._publisher_of_same_queue.set_is_add_publish_time()
         return self._publisher_of_same_queue
@@ -274,7 +273,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                  max_retry_times=3, log_level=10, is_print_detail_exception=True,
                  msg_schedule_time_intercal=0.0, qps: float = 0, is_using_distributed_frequency_control=False,
                  msg_expire_senconds=0, is_send_consumer_hearbeat_to_redis=False,
-                 logger_prefix='', create_logger_file=True, do_task_filtering=False,
+                 logger_prefix='', create_logger_file=False, do_task_filtering=False,
                  task_filtering_expire_seconds=0, is_consuming_function_use_multi_params=True,
                  is_do_not_run_by_specify_time_effect=False,
                  do_not_run_by_specify_time=('10:00:00', '22:00:00'),
@@ -381,7 +380,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self._is_send_consumer_hearbeat_to_redis = is_send_consumer_hearbeat_to_redis or is_using_distributed_frequency_control
         self._msg_expire_senconds = msg_expire_senconds
 
-        if self._concurrent_mode not in (1, 2, 3, 4):
+        if self._concurrent_mode not in (1, 2, 3, 4, 5):
             raise ValueError('设置的并发模式不正确')
         self._concurrent_mode_dispatcher = ConcurrentModeDispatcher(self)
         if self._concurrent_mode == 4:
@@ -510,6 +509,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
             self.keep_circulating(1)(self._shedual_task)()
         else:
             self._concurrent_mode_dispatcher.schedulal_task_with_no_block()
+        setattr(frame_config,'has_start_a_consumer_flag',1)
 
     @abc.abstractmethod
     def _shedual_task(self):
@@ -555,11 +555,11 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
             self._execute_task_times_every_unit_time += 1
             self._consuming_function_cost_time_total_every_unit_time += time.time() - t_start_run_fun
             if time.time() - self._current_time_for_execute_task_times_every_unit_time > self._unit_time_for_count:
-                self.logger.info(
-                    f'{self._unit_time_for_count} 秒内执行了 {self._execute_task_times_every_unit_time} 次函数 [ {self.consuming_function.__name__} ] ,'
-                    f'函数平均运行耗时 {round(self._consuming_function_cost_time_total_every_unit_time / self._execute_task_times_every_unit_time, 4)} 秒，预计'
-                    f'还需要 {time_util.seconds_to_hour_minute_second(self._msg_num_in_broker / self._execute_task_times_every_unit_time * self._unit_time_for_count)} 时间'
-                    f'才能执行完成 {self._msg_num_in_broker}个剩余的任务 ')
+                msg = f'''{self._unit_time_for_count} 秒内执行了 {self._execute_task_times_every_unit_time} 次函数 [ {self.consuming_function.__name__} ] ,
+                    函数平均运行耗时 {round(self._consuming_function_cost_time_total_every_unit_time / self._execute_task_times_every_unit_time, 4)} 秒'''
+                if self._msg_num_in_broker != -1:
+                    msg += f''' ，预计还需要 {time_util.seconds_to_hour_minute_second(self._msg_num_in_broker / self._execute_task_times_every_unit_time * self._unit_time_for_count)} 时间 才能执行完成 {self._msg_num_in_broker}个剩余的任务'''
+                self.logger.info(msg)
                 self._current_time_for_execute_task_times_every_unit_time = time.time()
                 self._consuming_function_cost_time_total_every_unit_time = 0
                 self._execute_task_times_every_unit_time = 0
@@ -645,11 +645,11 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self._execute_task_times_every_unit_time += 1
         self._consuming_function_cost_time_total_every_unit_time += time.time() - t_start_run_fun
         if time.time() - self._current_time_for_execute_task_times_every_unit_time > self._unit_time_for_count:
-            self.logger.info(
-                f'{self._unit_time_for_count} 秒内执行了 {self._execute_task_times_every_unit_time} 次函数 [ {self.consuming_function.__name__} ] ,'
-                f'函数平均运行耗时 {round(self._consuming_function_cost_time_total_every_unit_time / self._execute_task_times_every_unit_time, 4)} 秒，预计'
-                f'还需要 {time_util.seconds_to_hour_minute_second(self._msg_num_in_broker / self._execute_task_times_every_unit_time * self._unit_time_for_count)} 时间'
-                f'才能执行完成 {self._msg_num_in_broker}个剩余的任务 ')
+            msg = f'''{self._unit_time_for_count} 秒内执行了 {self._execute_task_times_every_unit_time} 次函数 [ {self.consuming_function.__name__} ] ,
+                               函数平均运行耗时 {round(self._consuming_function_cost_time_total_every_unit_time / self._execute_task_times_every_unit_time, 4)} 秒'''
+            if self._msg_num_in_broker != -1:
+                msg += f''' ，预计还需要 {time_util.seconds_to_hour_minute_second(self._msg_num_in_broker / self._execute_task_times_every_unit_time * self._unit_time_for_count)} 时间 才能执行完成 {self._msg_num_in_broker}个剩余的任务'''
+            self.logger.info(msg)
             self._current_time_for_execute_task_times_every_unit_time = time.time()
             self._consuming_function_cost_time_total_every_unit_time = 0
             self._execute_task_times_every_unit_time = 0
@@ -729,7 +729,8 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def check_heartbeat_and_message_count(self):
         self._msg_num_in_broker = self.publisher_of_same_queue.get_message_count()
         if time.time() - self._last_timestamp_print_msg_num > 60:
-            self.logger.info(f'[{self._queue_name}] 队列中还有 [{self._msg_num_in_broker}] 个任务')
+            if self._msg_num_in_broker != -1:
+                self.logger.info(f'[{self._queue_name}] 队列中还有 [{self._msg_num_in_broker}] 个任务')
             self._last_timestamp_print_msg_num = time.time()
         if self._msg_num_in_broker != 0:
             self._last_timestamp_when_has_task_in_queue = time.time()
@@ -741,8 +742,6 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         raise NotImplementedError
 
     def _submit_task(self, kw):
-        # print(kw)
-        # return         
         if self._judge_is_daylight():
             self._requeue(kw)
             time.sleep(self.time_interval_for_check_do_not_run_time)
@@ -760,7 +759,10 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
             self.__frequency_control(self._qps / active_num, self._msg_schedule_time_intercal * active_num)
         else:
             self.__frequency_control(self._qps, self._msg_schedule_time_intercal)
-        self.concurrent_pool.submit(self._run, kw)
+        if self._concurrent_mode == 5:  # 单线程
+            self._run(kw)
+        else:
+            self.concurrent_pool.submit(self._run, kw)
 
     def __frequency_control(self, qpsx, msg_schedule_time_intercalx):
         # 以下是消费函数qps控制代码。无论是单个消费者空频还是分布式消费控频，都是基于直接计算的，没有依赖redis inrc计数，使得控频性能好。
@@ -851,7 +853,7 @@ class ConcurrentModeDispatcher(LoggerMixin):
             ConsumersManager.schedulal_thread_to_be_join.append(t)
             t.start()
         else:
-            if self._concurrent_mode == 1:
+            if self._concurrent_mode in [1, 4, 5]:
                 t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
                 ConsumersManager.schedulal_thread_to_be_join.append(t)
                 t.start()
@@ -861,10 +863,11 @@ class ConcurrentModeDispatcher(LoggerMixin):
             elif self._concurrent_mode == 3:
                 g = eventlet.spawn(self.consumer.keep_circulating(1)(self.consumer._shedual_task), )
                 ConsumersManager.schedulal_thread_to_be_join.append(g)
-            elif self._concurrent_mode == 4:
-                t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
-                ConsumersManager.schedulal_thread_to_be_join.append(t)
-                t.start()
+            # elif self._concurrent_mode == 4:
+            #     t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
+            #     ConsumersManager.schedulal_thread_to_be_join.append(t)
+            #     t.start()
+            # elif self._concurrent_mode ==5:
 
 
 # noinspection DuplicatedCode
