@@ -70,7 +70,7 @@ class PriorityConsumingControlConfig:
 
 class PublishParamsChecker(LoggerMixin):
     """
-    发布的任务的函数参数检查，使发布的任务不会出现错误。
+    发布的任务的函数参数检查，使发布的任务在消费时候不会出现错误。
     """
 
     def __init__(self, func: typing.Callable):
@@ -103,7 +103,7 @@ class PublishParamsChecker(LoggerMixin):
 
 class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
-    def __init__(self, queue_name, log_level_int=10, logger_prefix='', is_add_file_handler=True,
+    def __init__(self, queue_name, log_level_int=10, logger_prefix='', is_add_file_handler=False,
                  clear_queue_within_init=False, is_add_publish_time=True, consuming_function: callable = None, ):
         """
         :param queue_name:
@@ -142,7 +142,7 @@ class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self.publish_msg_num_total = 0
         self._is_add_publish_time = is_add_publish_time
         self.__init_time = time.time()
-        atexit.register(self.__at_exit)
+        atexit.register(self._at_exit)
         if clear_queue_within_init:
             self.clear()
 
@@ -238,7 +238,7 @@ class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self.close()
         self.logger.warning(f'with中自动关闭publisher连接，累计推送了 {self.publish_msg_num_total} 条消息 ')
 
-    def __at_exit(self):
+    def _at_exit(self):
         self.logger.warning(
             f'程序关闭前，{round(time.time() - self.__init_time)} 秒内，累计推送了 {self.publish_msg_num_total} 条消息 到 {self._queue_name} 中')
 
@@ -254,11 +254,11 @@ def deco_mq_conn_error(f):
         # noinspection PyBroadException
         try:
             return f(self, *args, **kwargs)
-        except (PikaAMQPError, amqpstorm.AMQPError,KombuError) as e:  # except Exception as e:   # 现在装饰器用到了绝大多出地方，单个异常类型不行。ex
+        except (PikaAMQPError, amqpstorm.AMQPError, KombuError) as e:  # except Exception as e:   # 现在装饰器用到了绝大多出地方，单个异常类型不行。ex
             self.logger.error(f'中间件链接出错   ,方法 {f.__name__}  出错 ，{e}')
             self.init_broker()
             return f(self, *args, **kwargs)
         except Exception as e:
-            self.logger.critical(e,exc_info=True)
+            self.logger.critical(e, exc_info=True)
 
     return _deco_mq_conn_error
